@@ -25,8 +25,9 @@ remotes_list = param['remotes']
 ######################################
 ### Testing
 
-# remote = {'bucket': 'fire-emergency-nz', 'connection_config': 'https://b2.tethys-ts.xyz'}
-remote = {'bucket': 'nasa-data', 'connection_config': 'https://b2.tethys-ts.xyz'}
+remote = {'bucket': 'fire-emergency-nz', 'connection_config': 'https://b2.tethys-ts.xyz'}
+remote = {'bucket': 'es-hilltop', 'connection_config': 'https://b2.tethys-ts.xyz'}
+# remote = {'bucket': 'nasa-data', 'connection_config': 'https://b2.tethys-ts.xyz'}
 remote = remotes_list[-1]
 # remote['connection_config'] = 'https://b2.tethys-ts.xyz'
 #
@@ -49,6 +50,9 @@ station_ids = [station_id, '9f3ee54af239b845241f8f13']
 dataset_id = '38138ea1c3350031d1b217f6'
 station_id = 'b318207aa246e7bbbd74cb19'
 
+dataset_id = '4ae05d099af292fec48792ec'
+station_id = 'dfb66ed0f4835161a7001d45'
+
 #
 #
 self = Tethys([remote])
@@ -65,7 +69,7 @@ data1 = self.get_results(dataset_id, station_id, output='Dataset', cache='memory
 # data1 = self.get_results(dataset_id, station_id, output='Dict')
 # data1 = self.get_results(dataset_id, station_id, from_date='2012-01-02 00:00', output='Dataset')
 
-data1 = self.get_results(dataset_id, station_id, output='DataArray')
+data1 = self.get_results(dataset_id, station_id, squeeze_dims=True, output='DataArray', cache='memory')
 data2 = self.get_results(dataset_id, station_id2, output='DataArray')
 
 
@@ -83,106 +87,7 @@ data2 = self.get_results(dataset_id, geometry=query_geometry, squeeze_dims=True,
 
 stn = [s for s in stn_list1 if s['station_id'] == station_id]
 
-
-geom0 = [s['geometry'] for s in stn_list1]
-geom1 = [shape(s) for s in geom0]
-
-geom2 = [wkb.dumps(s) for s in geom1]
-geom3 = [wkb.loads(s) for s in geom2]
-
-geom2 = [s.wkt for s in geom1]
-geom3 = [wkt.loads(s) for s in geom2]
-
-
-strtree = STRtree(geom1)
-
-with open('strtree1.pickle', 'wb') as f:
-    pickle.dump(strtree, f, pickle.HIGHEST_PROTOCOL)
-
-with open('strtree1.pickle', 'rb') as f:
-    strtree1 = pickle.load(f)
-
-with open('geo1.pickle', 'wb') as f:
-    pickle.dump(geom2, f, pickle.HIGHEST_PROTOCOL)
-
-with open('geo2.pickle', 'wb') as f:
-    pickle.dump(geom0, f, pickle.HIGHEST_PROTOCOL)
-
-
-
-geo2 = {'dataset_id': dataset_id,
-        'station_id': [s['station_id'] for s in stn_list1] * 345,
-        'geometry': geom0 * 345
-        }
-
-with open('geo3.pickle', 'wb') as f:
-    pickle.dump(geo2, f, pickle.HIGHEST_PROTOCOL)
-
-
-json1 = orjson.dumps(geo2, option=orjson.OPT_SERIALIZE_NUMPY)
-
-gb1 = tu.write_json_zstd(geo2)
-
-geo3 = tu.read_json_zstd(gb1)
-
-geo4 = [shape(s) for s in geo3['geometry']]
-
-strtree = STRtree(geo4)
-
-gb2 = tu.write_json_zstd(stn_list1)
-
-
-geom_list = [s['geometry'] for s in stn_list1]
-stns = stn_list1.copy()
-
-query_geometry = {'type': 'Point', 'coordinates': [171.1, -43.1]}
-geom_query = shape(query_geometry).buffer(0.1)
-
-
-def get_nearest_station(stns, geom_query):
-    """
-
-    """
-    if isinstance(geom_query, dict):
-        geom_query = shape(geom_query)
-
-    geom1 = [shape(s['geometry']) for s in stns]
-    strtree = STRtree(geom1)
-    res = strtree.nearest(geom_query)
-    res_id = res.wkb_hex
-
-    stn_id_dict = {shape(s['geometry']).wkb_hex: s['station_id'] for s in stns}
-
-    stn_id = stn_id_dict[res_id]
-
-    return stn_id
-
-
-def get_intersected_stations(stns, geom_query):
-    """
-
-    """
-    if isinstance(geom_query, dict):
-        geom_query = shape(geom_query)
-
-    geom1 = [shape(s['geometry']) for s in stns]
-    strtree = STRtree(geom1)
-    res = strtree.query(geom_query)
-    res_ids = [r.wkb_hex for r in res]
-
-    stn_id_dict = {shape(s['geometry']).wkb_hex: s['station_id'] for s in stns}
-
-    stn_ids = [stn_id_dict[r] for r in res_ids]
-
-    return stn_ids
-
-
-
-
-
-
-
-
+stn = [s for s in stn_list1 if 'Waiau River' in s['ref']]
 
 
 
