@@ -28,7 +28,7 @@ pd.options.display.max_columns = 10
 ### Reference objects
 
 key_patterns = {'results': 'tethys/v2/{dataset_id}/{station_id}/{run_date}/results.nc.zst',
-                'results_buffer': 'tethys/v2/{dataset_id}/{station_id}/{run_date}/results_buffer.nc.zst',
+                # 'results_buffer': 'tethys/v2/{dataset_id}/{station_id}/{run_date}/results_buffer.nc.zst',
                 'datasets': 'tethys/v2/datasets.json.zst',
                 'stations': 'tethys/v2/{dataset_id}/stations.json.zst',
                 'station': 'tethys/v2/{dataset_id}/{station_id}/station.json.zst',
@@ -36,6 +36,7 @@ key_patterns = {'results': 'tethys/v2/{dataset_id}/{station_id}/{run_date}/resul
                 }
 
 b2_public_key_pattern = '{base_url}/file/{bucket}/{obj_key}'
+public_remote_key = 'https://b2.tethys-ts.xyz/file/tethysts/tethys/v2/public_remotes.json.zst'
 
 ##############################################
 ### Helper functions
